@@ -11,7 +11,7 @@ class Hdfs(FileIO):
     
     def __init__(self, storage_type=None):
         super().__init__()
-        self.web_hdfs_url = get_argument('hdfsUrl')
+        self.web_hdfs_url = get_argument('hdfsUrl').replace("hdfs://", "http://")
 
     def upload(self, local_path, remote_path, overwrite=True):
         # Upload model to HDFS
